@@ -5,3 +5,7 @@ class Config:
     @property
     def database_local_dump(self):
         return self.context.get("database", {}).get("local_dump", "dump/dump.db")
+
+    @property
+    def post_restore_script(self):
+        return self.context.get("database", {}).get("post_restore_script")
