@@ -20,7 +20,7 @@ def get_secret(region_name, secret_id, plain=False):
 
 def populate_env_from_secret(region_name, secret_id):
     """
-    Add environment variables from AWS secret
+    Add environment variables from AWS secret.
 
     It doesn't overwrite existing variables.
     """
@@ -31,7 +31,7 @@ def populate_env_from_secret(region_name, secret_id):
 @task(default=True)
 def mssh(c):
     """
-    SSH into production server (using AWS access key)
+    SSH into production server (using AWS access key).
 
     Requires AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY variables in environment.
     """
@@ -40,7 +40,7 @@ def mssh(c):
 
 @task
 def addkey(c):
-    """Add your id_rsa.pub to the production server for 60 seconds"""
+    """Add your id_rsa.pub to the production server for 60 seconds."""
     local(
         f"aws ec2-instance-connect send-ssh-public-key \
             --region {c.aws.region} \
@@ -54,6 +54,7 @@ def addkey(c):
 
 @task(addkey)
 def host(c):
+    """Return `username@hostname` that can be used in ssh."""
     import boto3
 
     ec2 = boto3.client("ec2", region_name=c["aws"]["region"])
@@ -65,7 +66,7 @@ def host(c):
 @task(name="dump")
 def database_dump(c):
     """
-    Create database dump (using AWS access key)
+    Create database dump (using AWS access key).
 
     Requires AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY variables in environment.
     """
